#!/bin/sh
# This script is used by xCAT to configure the LoadLeveler server nodes 
# when running with a database option.  The management server node should 
# have already initialized the DB using the llconfig -i command prior to 
# executing this script. 

POSTSCRIPT_PATH="LoadL"

UNAME=`uname -s`
if [[ ${UNAME} == "AIX" ]]; then
	ODBCINST="/usr/local/bin/odbcinst"
else
	ODBCINST="/usr/bin/odbcinst"
fi 

if [[ -f ${ODBCINST} ]]; then 
	if [[ -f $POSTSCRIPT_PATH/odbc.ini.user ]]; then 
		echo "Installing the user odbc.ini file ... "
		${ODBCINST} -i -s -h -f $POSTSCRIPT_PATH/odbc.ini.user
	fi 

	if [[ -f $POSTSCRIPT_PATH/odbc.ini.system ]]; then 
		echo "Installing the system odbc.ini file ... "
		${ODBCINST} -i -s -l -f $POSTSCRIPT_PATH/odbc.ini.system 
	fi

	if [[ -f ${POSTSCRIPT_PATH}/LoadL.cfg.server ]]; then 
		echo "Copying the LoadL.cfg file to /etc ... "
		/bin/cp ${POSTSCRIPT_PATH}/LoadL.cfg.server /etc/LoadL.cfg
		/bin/chmod 644 /etc/LoadL.cfg
	fi

else
	echo "ERROR: The file ${ODBCINST} is not avaiable on this machine.  Verify that unixODBC has been installed." 
fi

USER=`cat /etc/LoadL.cfg | grep -i loadluserid | sed 's/ //g' | cut -d'=' -f2`
GROUP=`cat /etc/LoadL.cfg | grep -i loadlgroupid | sed 's/ //g' | cut -d'=' -f2`


# Create the odbc entry for the home directory of loadl
if [[ -f $POSTSCRIPT_PATH/odbc.ini.user ]]; then 
	echo "Installing the user odbc.ini file for the LoadLUserID: ${USER}" 
	/bin/su - ${USER} -c "/usr/local/bin/odbcinst -i -s -h -f `pwd`/$POSTSCRIPT_PATH/odbc.ini.user"
fi

if [[ -f $POSTSCRIPT_PATH/odbc.ini.user ]]; then
	/bin/rm $POSTSCRIPT_PATH/odbc.ini.user
fi

if [[ -f $POSTSCRIPT_PATH/odbc.ini.system ]]; then
	/bin/rm $POSTSCRIPT_PATH/odbc.ini.system
fi

# creating the log/spool/execute directories with the LoadLeveler
# user/group defined in LoadL.cfg. The directories are created with 
# the following permissions:
#	log 	775
#	spool 	700 
# 	execute	1777

DIR_CONFIG_FILE="${POSTSCRIPT_PATH}/ll_config_directories"

while read line
do
	echo "Creating directory: $line"
	eval "/bin/mkdir -p $line"
	eval "/bin/chmod 777 $line"
	eval "/bin/chown -R ${USER}:${GROUP} $line"

	KW=${line##*/}
	if [[ ${KW} == "log" ]] ; then 
		eval "/bin/chmod 775 $line"
	elif [[ ${KW} == "spool" ]] ; then 
		eval "/bin/chmod 700 $line"
	elif [[ ${KW} == "execute" ]] ; then 
		eval "/bin/chmod 1777 $line"
	else 
		echo "error processing line: $line"
		exit -1
	fi
done < ${DIR_CONFIG_FILE}

